@@ -2,10 +2,6 @@
 #' 
 #' @description  Creates a plot of series 10777
 #' 
-#' @param start A \code{character}. The stating period of the series.
-#' @param ylim A \code{numeric vector}. Y axis limits.
-#' @param xlim  A \code{numeric vector}. x axis limits.
-#' 
 #' @return An image file is saved in the 'graphs' folder, under the BETS installation directory. 
 #' 
 #' @importFrom grDevices dev.new dev.off  pdf  png
@@ -14,14 +10,15 @@
 #' @importFrom stats ts plot.ts
 #' @importFrom graphics axis text  points  mtext arrows
 
-draw.unemp = function(start = NULL, ylim = NULL, xlim = NULL){
+draw.unemp = function(){
   
-  unemp = BETS.get(10777)
+  unemp = BETS.get(24369)
+  # start = c(2006,1)
+  # 
+  # if(!is.null(start)){
+  #   unemp = window(unemp, start = start)
+  # }
   
-  if(!is.null(start)){
-    unemp = window(unemp, start = start)
-  }
-  
-  lims = chart.add_basic(ts = unemp, ylim = c(4,14), title = "Open Unemployment Rate", subtitle = "Metropolitan Regions", col = "royalblue", trend = TRUE)
+  lims = chart.add_basic(ts = unemp, ylim = c(4,14), title = "Unemployment Rate (PNAD-C)", subtitle = "Metropolitan Regions", col = "royalblue", trend = TRUE, leg.pos = "bottom")
   chart.add_notes(unemp, ylim = lims[3:4], xlim = lims[1:2])
 }
\ No newline at end of file
