@@ -5,11 +5,13 @@
 #' @param save A string specifying if data should be saved in csv or xlsx format. 
 #' Defaults to not saving.
 #' @keywords bacen
-#' @author Fernando Teixeira \email{fernando.teixeira@fgv.br}
+#' @author Fernando Teixeira \email{fernando.teixeira@fgv.br} and Jonatha Azevedo 
+#' \email{jonatha.costa@fgv.br}
 #' @import RCurl 
+#' @importFrom httr GET content
+
+get.series.bacen<- function(x, from = "", to = "",save = ""){
 
-get.series.bacen <- function(x, from = "", to = "", save = ""){
-  
   
   if (missing(x)){
     stop("Need to specify at least one serie.")
@@ -57,14 +59,52 @@ get.series.bacen <- function(x, from = "", to = "", save = ""){
     assign(serie[i], result) 
   }
   
-  for (i in len){
-    texto = utils::read.csv2(textConnection(eval(as.symbol(
-      serie[i]))), header=T)
-    texto$data = gsub(' .*$','', eval(texto$data))
-    assign(serie[i], texto)
-    
-  }
   
+ sinal = tryCatch({
+        for (i in len){
+            texto = utils::read.csv2(textConnection(eval(as.symbol(
+            serie[i]))), header=T)
+            texto$data = gsub(' .*$','', eval(texto$data))
+            assign(serie[i], texto)
+    
+  }},
+  error = function(e){
+      return("error")
+  })
+ 
+ 
+ 
+ if(sinal == "error"){
+     for(i in len){
+     texto=tryCatch({
+         k = paste0('http://api.bcb.gov.br/dados/serie/bcdata.sgs.',
+                    inputs[i], 
+                    '/dados?formato=csv&dataInicial=', data_init, '&dataFinal=',
+                    data_end)
+         dados = GET(k)
+         aux = content(dados,'raw')
+         aux2=rawToChar(aux)
+         
+         DF <- data.frame(do.call(cbind, strsplit(aux2, "\r\n", fixed=TRUE)))
+         names(DF) <-"mist"
+         DF$mist <- as.character(DF$mist)
+         DF$mist<- gsub(x = DF$mist,pattern = '"',replacement = "")
+         DF$data <- gsub(x = DF$mist,pattern = ";.*",replacement = "")
+         DF$valor <- gsub(x = DF$mist,pattern = ".*;",replacement = "")
+         DF$valor <- gsub(x = DF$valor,pattern = ",",replacement = ".")
+         DF <- DF[-1,-1]
+     })}
+     assign(serie[i], result)
+    }
+  
+ if(sinal == "error"){
+     for (i in len){
+     texto$data = gsub(' .*$','', eval(texto$data))
+     assign(serie[i], texto)
+     }
+ }
+ 
+ 
   if(ncol(texto) == 1){
     for (i in len){
       texto = utils::read.csv(textConnection(eval(as.symbol(
@@ -74,13 +114,8 @@ get.series.bacen <- function(x, from = "", to = "", save = ""){
     }
   }
   
-  rm(texto)
-  
-  if (save == "csv"){
-    for(i in len) {utils::write.csv(eval(as.symbol(serie[i])), file = paste0(serie[i], ".csv"))}
-    
-  }
-  
+ rm(texto) 
+ 
   lista = list()
   ls_df = ls()[grepl('data.frame', sapply(ls(), function(x) class(get(x))))]
   for ( obj in ls_df ) { lista[obj]=list(get(obj)) }
